## 南华期货指数日线行情

接口：index_daily

描述：获取南华指数每日行情，指数行情也可以通过通用行情接口获取数据．

权限：用户需要累积2000积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 指数代码（南华期货指数以 .NH 结尾，具体请参考本文最下方） |
| trade_date | str | N | 交易日期 （日期格式：YYYYMMDD，下同） |
| start_date | str | N | 开始日期 |
| end_date | None | N | 结束日期 |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| ts_code | str | TS指数代码 |
| trade_date | str | 交易日 |
| close | float | 收盘点位 |
| open | float | 开盘点位 |
| high | float | 最高点位 |
| low | float | 最低点位 |
| pre_close | float | 昨日收盘点 |
| change | float | 涨跌点 |
| pct_chg | float | 涨跌幅 |
| vol | float | 成交量（手） |
| amount | float | 成交额（千元） |

接口使用

```python
pro = ts.pro_api()

#获取南华沪铜指数
df = pro.index_daily(ts_code='CU.NH', start_date='20180101', end_date='20181201')
```

数据样例

```python
ts_code trade_date     close      open      high       low  pre_close  \
0     CU.NH   20181130  3928.773  3918.501  3928.773  3907.438   3916.130   
```

| 指数代码 | 指数名称 |
| --- | --- |
| NHAI.NH | 南华农产品指数 |
| NHCI.NH | 南华商品指数 |
| NHECI.NH | 南华能化指数 |
| NHFI.NH | 南华黑色指数 |
| NHII.NH | 南华工业品指数 |
| NHMI.NH | 南华金属指数 |
| NHNFI.NH | 南华有色金属 |
| NHPMI.NH | 南华贵金属指数 |
| A.NH | 南华连大豆指数 |
| AG.NH | 南华沪银指数 |
| AL.NH | 南华沪铝指数 |
| AP.NH | 南华郑苹果指数 |
| AU.NH | 南华沪黄金指数 |
| BB.NH | 南华连胶合板指数 |
| BU.NH | 南华沪石油沥青指数 |
| C.NH | 南华连玉米指数 |
| CF.NH | 南华郑棉花指数 |
| CS.NH | 南华连玉米淀粉指数 |
| CU.NH | 南华沪铜指数 |
| CY.NH | 南华棉纱指数 |
| ER.NH | 南华郑籼稻指数 |
| FB.NH | 南华连纤维板指数 |
| FG.NH | 南华郑玻璃指数 |
| FU.NH | 南华沪燃油指数 |
| HC.NH | 南华沪热轧卷板指数 |
| I.NH | 南华连铁矿石指数 |
| J.NH | 南华连焦炭指数 |
| JD.NH | 南华连鸡蛋指数 |
| JM.NH | 南华连焦煤指数 |
| JR.NH | 南华郑粳稻指数 |
| L.NH | 南华连乙烯指数 |
| LR.NH | 南华郑晚籼稻指数 |
| M.NH | 南华连豆粕指数 |
| ME.NH | 南华郑甲醇指数 |
| NI.NH | 南华沪镍指数 |
| P.NH | 南华连棕油指数 |
| PB.NH | 南华沪铅指数 |
| PP.NH | 南华连聚丙烯指数 |
| RB.NH | 南华沪螺钢指数 |
| RM.NH | 南华郑菜籽粕指数 |
| RO.NH | 南华郑菜油指数 |
| RS.NH | 南华郑油菜籽指数 |
| RU.NH | 南华沪天胶指数 |
| SC.NH | 南华原油指数 |
| SF.NH | 南华郑硅铁指数 |
| SM.NH | 南华郑锰硅指数 |
| SN.NH | 南华沪锡指数 |
| SP.NH | 南华纸浆指数 |
| SR.NH | 南华郑白糖指数 |
| TA.NH | 南华郑精对苯二甲酸指数 |
| TC.NH | 南华郑动力煤指数 |
| V.NH | 南华连聚氯乙烯指数 |
| WR.NH | 南华沪线材指数 |
| WS.NH | 南华郑强麦指数 |
| Y.NH | 南华连豆油指数 |
| ZN.NH | 南华沪锌指数 |